| Title: | Interactive Plotting for Funnel and Statistical Process Control Charts |
|---|---|
| Description: | Generate fully interactive and dynamic funnel plots and statistical process control (SPC) charts. All data manipulation, calculation, and plotting is done in JavaScript, allowing for completely dynamic charts without the need for a Shiny server. |
| Authors: | Andrew R. Johnson [aut, cre] (ORCID: <https://orcid.org/0000-0001-7000-8065>), Healthcare Quality Intelligence Unit (Western Australia Health) [aut] |
| Maintainer: | Andrew R. Johnson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.13 |
| Built: | 2026-06-08 05:32:37 UTC |
| Source: | https://github.com/AUS-DOH-Safety-and-Quality/controlcharts |
Generate interactive Funnel chart
funnel( data, keys, numerators, denominators, tooltips, labels, aggregations = list(numerators = "sum", denominators = "sum", tooltips = "first", labels = "first"), title = NULL, canvas_settings = NULL, funnel_settings = NULL, outlier_settings = NULL, scatter_settings = NULL, line_settings = NULL, x_axis_settings = NULL, y_axis_settings = NULL, label_settings = NULL, tooltip_settings = NULL, width = NULL, height = NULL, elementId = NULL, return_objs = c("html_plot", "static_plot", "limits") )funnel( data, keys, numerators, denominators, tooltips, labels, aggregations = list(numerators = "sum", denominators = "sum", tooltips = "first", labels = "first"), title = NULL, canvas_settings = NULL, funnel_settings = NULL, outlier_settings = NULL, scatter_settings = NULL, line_settings = NULL, x_axis_settings = NULL, y_axis_settings = NULL, label_settings = NULL, tooltip_settings = NULL, width = NULL, height = NULL, elementId = NULL, return_objs = c("html_plot", "static_plot", "limits") )
data |
A data frame containing the data for the chart. |
keys |
A vector or column name representing the categories of the chart. |
numerators |
A numeric vector or column name representing the numerators for each category. |
denominators |
A numeric vector or column name representing the denominators for each category. |
tooltips |
A vector or column name representing the tooltips for each category. |
labels |
A vector or column name representing the labels for each category. |
aggregations |
A list of aggregation function names for each field if multiple values are provided for each key. Valid options are:
|
title |
Optional title to be added to the top of the chart. It can be a character string for the title text only, or a list with the following options:
|
canvas_settings |
Optional list of settings for the canvas,
see |
funnel_settings |
Optional list of settings for the Funnel chart,
see |
outlier_settings |
Optional list of settings for outliers,
see |
scatter_settings |
Optional list of settings for scatter points,
see |
line_settings |
Optional list of settings for lines,
see |
x_axis_settings |
Optional list of settings for the x-axis,
see |
y_axis_settings |
Optional list of settings for the y-axis,
see |
label_settings |
Optional list of settings for labels,
see |
tooltip_settings |
Optional list of settings for tooltips,
see |
width |
Optional width of the chart in pixels. If NULL (default), the chart will fill the width of its container. |
height |
Optional height of the chart in pixels. If NULL (default), the chart will fill the height of its container. |
elementId |
Optional HTML element ID for the chart. |
return_objs |
Character vector of object types to return. Valid values are:
|
An object of class controlchart containing the
interactive plot, static plot, limits data frame, raw data,
and a function to save the plot.
Get default settings for Funnel charts Retrieve the default settings for Funnel charts or a specific settings group.
funnel_default_settings(group = NULL)funnel_default_settings(group = NULL)
group |
Optional. A specific settings group to retrieve. If NULL, all settings groups are returned. |
A list of default settings for Funnel charts or the specified settings group.
#' # Get all default settings for Funnel charts funnel_default_settings() # # Get default settings for a specific group funnel_default_settings("x_axis")#' # Get all default settings for Funnel charts funnel_default_settings() # # Get default settings for a specific group funnel_default_settings("x_axis")
Output and render functions for using wrapper within Shiny applications and interactive Rmd documents.
funnelOutput(outputId, width = "100%", height = "400px") renderfunnel(expr, env = parent.frame(), quoted = FALSE)funnelOutput(outputId, width = "100%", height = "400px") renderfunnel(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a wrapper |
env |
The environment in which to evaluate |
quoted |
Is |
Generate interactive SPC chart
spc( data, keys, numerators, denominators, groupings, xbar_sds, tooltips, labels, aggregations = list(numerators = "sum", denominators = "sum", groupings = "first", xbar_sds = "first", tooltips = "first", labels = "first"), title = NULL, canvas_settings = NULL, spc_settings = NULL, outlier_settings = NULL, nhs_icon_settings = NULL, scatter_settings = NULL, line_settings = NULL, x_axis_settings = NULL, y_axis_settings = NULL, date_settings = NULL, label_settings = NULL, tooltip_settings = NULL, width = NULL, height = NULL, elementId = NULL, return_objs = c("html_plot", "static_plot", "limits") )spc( data, keys, numerators, denominators, groupings, xbar_sds, tooltips, labels, aggregations = list(numerators = "sum", denominators = "sum", groupings = "first", xbar_sds = "first", tooltips = "first", labels = "first"), title = NULL, canvas_settings = NULL, spc_settings = NULL, outlier_settings = NULL, nhs_icon_settings = NULL, scatter_settings = NULL, line_settings = NULL, x_axis_settings = NULL, y_axis_settings = NULL, date_settings = NULL, label_settings = NULL, tooltip_settings = NULL, width = NULL, height = NULL, elementId = NULL, return_objs = c("html_plot", "static_plot", "limits") )
data |
A data frame containing the data for the chart. |
keys |
A vector or column name representing the categories (x-axis) of the chart. |
numerators |
A numeric vector or column name representing the numerators for each category. |
denominators |
A numeric vector or column name representing the denominators for each category. |
groupings |
A vector or column name representing the grouping for each category. |
xbar_sds |
A numeric vector or column name representing the x-bar and standard deviation values for each category. |
tooltips |
A vector or column name representing the tooltips for each category. |
labels |
A vector or column name representing the labels for each category. |
aggregations |
A list of aggregation function names for each field if multiple values are provided for each key. Valid options are:
|
title |
Optional title to be added to the top of the chart. It can be a character string for the title text only, or a list with the following options:
|
canvas_settings |
Optional list of settings for the canvas,
see |
spc_settings |
Optional list of settings for the SPC chart,
see |
outlier_settings |
Optional list of settings for outliers,
see |
nhs_icon_settings |
Optional list of settings for NHS icons,
see |
scatter_settings |
Optional list of settings for scatter points,
see |
line_settings |
Optional list of settings for lines,
see |
x_axis_settings |
Optional list of settings for the x-axis,
see |
y_axis_settings |
Optional list of settings for the y-axis,
see |
date_settings |
Optional list of settings for dates,
see |
label_settings |
Optional list of settings for labels,
see |
tooltip_settings |
Optional list of settings for tooltips,
see |
width |
Optional width of the chart in pixels. If NULL (default), the chart will fill the width of its container. |
height |
Optional height of the chart in pixels. If NULL (default), the chart will fill the height of its container. |
elementId |
Optional HTML element ID for the chart. |
return_objs |
Character vector of object types to return. Valid values are:
|
An object of class controlchart containing the
interactive plot, static plot, limits data frame,
and a function to save the plot.
Retrieve the default settings for SPC charts or a specific settings group.
spc_default_settings(group = NULL)spc_default_settings(group = NULL)
group |
Optional. A specific settings group to retrieve. If NULL, all settings groups are returned. |
A list of default settings for SPC charts or the specified settings group.
#' # Get all default settings for SPC charts spc_default_settings() # # Get default settings for a specific group spc_default_settings("x_axis")#' # Get all default settings for SPC charts spc_default_settings() # # Get default settings for a specific group spc_default_settings("x_axis")
Output and render functions for using wrapper within Shiny applications and interactive Rmd documents.
spcOutput(outputId, width = "100%", height = "400px") renderSpc(expr, env = parent.frame(), quoted = FALSE)spcOutput(outputId, width = "100%", height = "400px") renderSpc(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a wrapper |
env |
The environment in which to evaluate |
quoted |
Is |